#!/bin/sh
# 
# Initialize the environment with EDG-specific profile.d scripts.
#
# Note: this script should be run only after the top-level EDG profile.d
# script runs so that EDG_LOCATION and EDG_LOCATION_VAR are properly
# defined.  Moreoever, we guarantee that the Globus variables are also 
# initialized, so the Globus profile.d should also run before this. 
#
# Look first in EDG_LOCATION_VAR.  If it exists use only those scripts in
# that directory.  If not, move on to EDG_LOCATION. 
#

if test "x${LCG_ENV_SET+x}" = x; then

    # Patch for zsh users.
    if [ -n "$ZSH_NAME" ]; then
	setopt SH_WORD_SPLIT
    fi


    # List of files to source and list of basenames already in list.
    slist=""
    dlist=""

    # Look in EDG_LOCATION_VAR first.  Keep track of the base names to 
    # exclude doing one setup twice. 
    if [ -n "${EDG_LOCATION_VAR}" -a -d ${EDG_LOCATION_VAR}/etc/profile.d ]; then
	for i in ${EDG_LOCATION_VAR}/etc/profile.d/*.sh ; do
	    if [ -x ${i} ]; then
		slist=${slist}" "${i}
		dlist=${dlist}" "`basename ${i}`
	    fi
	done
	unset i
    fi

    # Now look in normal EDG_LOCATION excluding those already done.
    if [ -n "${EDG_LOCATION}" -a -d ${EDG_LOCATION}/etc/profile.d ]; then
	for i in ${EDG_LOCATION}/etc/profile.d/*.sh ; do
	    if [ -x ${i} ]; then
		bn=`basename ${i}`
		if [ -z "`echo ${slist} | grep ${bn}`" ]; then
		  slist=${slist}" "${i}
		fi
		unset bn
	    fi
	done
	unset i
    fi

    # Now source the complete list of files. 
    for i in ${slist} ; do
	. ${i}
    done
    unset i

    # Clean up.
    unset slist
    unset dlist
fi
